ksampleA2 provides the Anderson-Darling test statistic;
nonparboot provides a non-parametric bootstrap;
test.GOFmontecarlo is used to test the type I error of goodness of fit tests GOFmontecarlo.
typeIerrorA2_GOFlaio is used to test the type I error of goodness of fit tests A2_GOFlaio.
fw2 is the approximation of the probability distribution of w (first 2 terms) when $H_0$ is true (Anderson-Darling, 1952); it is used by A2_GOFlaio.
ksampleA2 (x,cod)
nonparboot (z,n=length(z))
test.GOFmontecarlo (parameters, type="NORM", alfa=.05, n=30, N=100)
typeIerrorA2_GOFlaio (n, T, alfa=0.05, dist="NORM", Nsim=1000)
fw2 (w)codnonparboot)"NORM", "GENLOGIS", "GENPAR", "GEV", "LOGNORM", "P3""NORM", "LN", "EV1", "EV2", "GEV", "GAM", "LP3")N