nsRFA-package: Non-supervised Regional Frequency Analysis
Description
A collection of statistical tools for objective (non-supervised) applications
of the Regional Frequency Analysis methods in hydrology.
Arguments
Details
ll{
Package: nsRFA
Type: Package
Version: 0.5-2
Date: 2008-04-22
License: GPL (>= 2)
}
The package provides several tools for Regional Frequency Analysis of hydrological variables.
The first version dates to 2006 and was developed in Turin at the Politecnico by Alberto Viglione.
~~ An overview of how to use the package, including the most important ~~
~~ functions ~~
References
~~ Literature or other references for background information ~~
See Also
~~ Optional links to other man pages, e.g. ~~
~~ ~~